[yt-svn] commit/yt: 2 new changesets

Bitbucket commits-noreply at bitbucket.org
Tue Feb 5 16:15:41 PST 2013


2 new commits in yt:

https://bitbucket.org/yt_analysis/yt/commits/2ed83279566f/
changeset:   2ed83279566f
branch:      yt
user:        ngoldbaum
date:        2013-02-05 23:30:06
summary:     Updating the OS X notes on the install script.
affected #:  1 file

diff -r 5794d91ad696569ad43c004ed7880887ec041f58 -r 2ed83279566f3e4868b916ce7cb0d1b18ab16349 doc/install_script.sh
--- a/doc/install_script.sh
+++ b/doc/install_script.sh
@@ -176,24 +176,55 @@
         echo
         echo "NOTE: you must have the Xcode command line tools installed."
         echo
-        echo "OS X 10.5: download Xcode 3.0 from the mac developer tools"
-        echo "website"
+	echo "The instructions for obtaining these tools varies according"
+	echo "to your exact OS version.  On older versions of OS X, you"
+	echo "must register for an account on the apple developer tools"
+	echo "website: https://developer.apple.com/downloads to obtain the"
+	echo "download link."
+	echo 
+	echo "We have gathered some additional instructions for each"
+	echo "version of OS X below.  If you have trouble setting up Xcode"
+	echo "after following these instructions, don't hesitate to contact"
+	echo "the yt user's e-mail list."
+	echo
+	echo "You can see which version of OSX you are running by clicking"
+	echo "'About This Mac' in the apple menu on the left hand side of"
+	echo "menu bar."
+	echo 
+        echo "OS X 10.5.8: search for and download Xcode 3.1.4 from the" 
+	echo "Apple developer tools website."
         echo
-        echo "OS X 10.6: download Xcode 3.2 from the mac developer tools"
-        echo "website"
+        echo "OS X 10.6.8: search for download Xcode 3.2 from the Apple"
+	echo "developer tools website.  You can either download the"
+	echo "Xcode 3.2.2 Developer Tools package (744 MB) and then use"
+	echo "Software Update to update to XCode 3.2.6 or" 
+	echo "alternatively, you can download the Xcode 3.2.6/iOS SDK" 
+	echo "bundle (4.1 GB)."
         echo
-        echo "OS X 10.7: download Xcode 4.0 from the mac app store or"
-        echo "alternatively download the Xcode command line tools from"
-        echo "the mac developer tools website"
+        echo "OS X 10.7.5: download Xcode 4.2 from the mac app store"
+	echo "(search for Xcode)."
+        echo "Alternatively, download the Xcode command line tools from"
+        echo "the Apple developer tools website."
         echo
-        echo "NOTE: You may have problems if you are running OSX 10.6 (Snow"
-        echo "Leopard) or newer.  If you do, please set the following"
-        echo "environment variables, remove any broken installation tree, and"
-        echo "re-run this script verbatim."
+	echo "OS X 10.8.2: download Xcode 4.6 from the mac app store."
+	echo "(search for Xcode)."
+	echo "Additionally, you will have to manually install the Xcode"
+	echo "command line tools, see:" 
+	echo "http://stackoverflow.com/questions/9353444"
+	echo "Alternatively, download the Xcode command line tools from"
+	echo "the Apple developer tools website."
+	echo
+        echo "NOTE: It's possible that the installation will fail, if so," 
+	echo "please set the following environment variables, remove any" 
+	echo "broken installation tree, and re-run this script verbatim."
         echo
         echo "$ export CC=gcc-4.2"
         echo "$ export CXX=g++-4.2"
         echo
+	echo "If the installation fails with these environment variables"
+	echo "set, we're happy to offer some additional help on the yt"
+	echo "user's mailing list."
+	echo
         OSX_VERSION=`sw_vers -productVersion`
         if [ "${OSX_VERSION##10.8}" != "${OSX_VERSION}" ]
         then


https://bitbucket.org/yt_analysis/yt/commits/c57b08a8a710/
changeset:   c57b08a8a710
branch:      yt
user:        ngoldbaum
date:        2013-02-06 01:04:52
summary:     Adding some scipy notes and warning about being up to date on OSX point releases.
affected #:  1 file

diff -r 2ed83279566f3e4868b916ce7cb0d1b18ab16349 -r c57b08a8a710c0fab9b5b8da6bb550f65b8177a4 doc/install_script.sh
--- a/doc/install_script.sh
+++ b/doc/install_script.sh
@@ -26,7 +26,7 @@
 # and install it on its own
 #HDF5_DIR=
 
 # If you need to supply arguments to the NumPy build, supply them here
 # This one turns on gfortran manually:
 #NUMPY_ARGS="--fcompiler=gnu95"
 # If you absolutely can't get the fortran to work, try this:
@@ -183,18 +183,20 @@
 	echo "download link."
 	echo 
 	echo "We have gathered some additional instructions for each"
-	echo "version of OS X below.  If you have trouble setting up Xcode"
+	echo "version of OS X below. If you have trouble setting up Xcode"
 	echo "after following these instructions, don't hesitate to contact"
 	echo "the yt user's e-mail list."
 	echo
 	echo "You can see which version of OSX you are running by clicking"
 	echo "'About This Mac' in the apple menu on the left hand side of"
-	echo "menu bar."
+	echo "menu bar.  We're assuming that you've installed all operating"
+	echo "system updates; if you have an older version, we suggest"
+	echo "running software update and installing all available updates."
 	echo 
         echo "OS X 10.5.8: search for and download Xcode 3.1.4 from the" 
 	echo "Apple developer tools website."
         echo
-        echo "OS X 10.6.8: search for download Xcode 3.2 from the Apple"
+        echo "OS X 10.6.8: search for and download Xcode 3.2 from the Apple"
 	echo "developer tools website.  You can either download the"
 	echo "Xcode 3.2.2 Developer Tools package (744 MB) and then use"
 	echo "Software Update to update to XCode 3.2.6 or" 
@@ -222,8 +224,8 @@
         echo "$ export CXX=g++-4.2"
         echo
 	echo "If the installation fails with these environment variables"
-	echo "set, we're happy to offer some additional help on the yt"
-	echo "user's mailing list."
+	echo "set, don't hesitate to ask for help on the yt user's mailing"
+	echo "list."
 	echo
         OSX_VERSION=`sw_vers -productVersion`
         if [ "${OSX_VERSION##10.8}" != "${OSX_VERSION}" ]
@@ -263,6 +265,19 @@
         echo " to avoid conflicts with other command-line programs "
         echo " (like eog and evince, for example)."
     fi
+    if [$INST_SCIPY -eq 1]
+    then
+	echo
+	echo "Looks like you've requested that the install script build scipy."
+	echo
+	echo "If the scipy build fails, please uncomment the line at the top of"
+	echo "the install script that sets NUMPY_ARGS, delete any broken"
+	echo "installation tree, and re-run the install script verbatim."
+	echo
+	echo "If that doesn't work, don't hesitate to ask for help on the yt"
+	echo "user's mailing list."
+	echo
+    fi
     if [ ! -z "${CFLAGS}" ]
     then
         echo "******************************************"
@@ -26,7 +26,7 @@
 #HDF5_DIR=
 
-# If you need to supply arguments to the NumPy build, supply them here
+# If you need to supply arguments to the NumPy and scipy build, supply them here
 # This one turns on gfortran manually:
 #NUMPY_ARGS="--fcompiler=gnu95"

Repository URL: https://bitbucket.org/yt_analysis/yt/

--

This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.



More information about the yt-svn mailing list